@@ -5,7 +5,7 @@ audio commands.
 import json
 import click
 
-from .utils.request import delete, get, post
+from .utils.request import delete, get, post, patch
 
 
 @click.group()
@@ -138,6 +138,12 @@ audio.add_command(search_tracks)
 
 
 @click.command()
+@click.option(
+    "--language",
+    multiple=False,
+    help="Which language the genres will be returned",
+    type=str,
+)
 def list_genres(**kwargs):
     """
     List audio genres
@@ -226,7 +232,7 @@ def license_track(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/audio/licenses", params=kwargs, json_data=json_data)
@@ -313,7 +319,7 @@ def create_track_collection(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/audio/collections", params=kwargs, json_data=json_data)
@@ -387,7 +393,7 @@ def rename_track_collection(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
@@ -429,7 +435,7 @@ def add_track_collection_items(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
