@@ -5,7 +5,7 @@ images commands.
 import json
 import click
 
-from .utils.request import delete, get, post
+from .utils.request import delete, get, post, patch
 
 
 @click.group()
@@ -286,7 +286,7 @@ def get_image_keyword_suggestions(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/images/search/suggestions", params=kwargs, json_data=json_data)
@@ -392,7 +392,7 @@ def license_images(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/images/licenses", params=kwargs, json_data=json_data)
@@ -463,7 +463,7 @@ def download_image(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
@@ -511,7 +511,7 @@ def create_image_collection(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/images/collections", params=kwargs, json_data=json_data)
@@ -587,7 +587,7 @@ def rename_image_collection(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
@@ -629,7 +629,7 @@ def add_image_collection_items(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
