@@ -5,7 +5,7 @@ videos commands.
 import json
 import click
 
-from .utils.request import delete, get, post
+from .utils.request import delete, get, post, patch
 
 
 @click.group()
@@ -283,7 +283,7 @@ def license_videos(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/videos/licenses", params=kwargs, json_data=json_data)
@@ -356,7 +356,7 @@ def download_videos(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
@@ -382,7 +382,7 @@ def create_video_collection(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(url="/v2/videos/collections", params=kwargs, json_data=json_data)
@@ -458,7 +458,7 @@ def rename_video_collection(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
@@ -518,7 +518,7 @@ def add_video_collection_items(**kwargs):
     """
 
     try:
-        with open(kwargs["data"]) as input_data:
+        with open(kwargs["data"], encoding="UTF-8") as input_data:
             json_data = json.load(input_data)
 
         post(
